SerialLines

Struct SerialLines 

pub struct SerialLines<ReaderTy> { /* private fields */ }
Reads serial lines from an AsyncBufRead.

This tries to act a lot like the structure returned from .lines() on a normal async buf reader. Except instead of splitting on \n, we use \r.

Implementations

Source

impl<ReaderTy> SerialLines<ReaderTy>
where ReaderTy: AsyncBufRead + Unpin,

pub async fn next_line(&mut self) -> IoResult<Option<String>>

Grab the next line from the serial line reader.

Errors

If we get an IoError back from the underlying reader we’re reading from.

Source

impl<ReaderTy> SerialLines<ReaderTy>
where ReaderTy: AsyncBufRead,

pub fn new(reader: ReaderTy) -> Self

Create a new Serial Lines reader.

pub const fn get_ref(&self) -> &ReaderTy

Get a constant reference to the current reader type.

pub const fn get_mut(&mut self) -> &mut ReaderTy

Get a mutable reference to the current reader type.

pub fn poll_next_line( self: Pin<&mut Self>, cx: &mut Context<'_>, ) -> Poll<IoResult<Option<String>>>

Polls for the next line in the stream.

This method returns:

  • Poll::Pending if the next line is not yet available.
  • Poll::Ready(Ok(Some(line))) if the next line is available.
  • Poll::Ready(Ok(None)) if there are no more lines in this stream.
  • Poll::Ready(Err(err)) if an IO error occurred while reading the next line.

When the method returns Poll::Pending, the Waker in the provided Context is scheduled to receive a wakeup when more bytes become available on the underlying IO resource. Note that on multiple calls to poll_next_line, only the Waker from the Context passed to the most recent call is scheduled to receive a wakeup.